==> ejc-businessplan-impl-3.0.0-20220608.041926-76-sources.jar: com/ejianc/business/busniessplan/vo/PlanprojectdetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目商务策划立项子表
 * 
 * @author generator
 * 
 */
public class PlanprojectdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String tid;
    private java.lang.String shadowId;
    private java.lang.String tpid;
    private java.lang.String sort; // 序号
    private java.lang.String categoryAndName; // 类别及项目名称
    private java.lang.String initiateReason; // 立项理由及依据
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date initiateDate; // 立项时间
    private java.lang.String initiateDateShow; //立项时间文本显示
    private java.math.BigDecimal costEstimate; // 成本估算(成本分析)(元)
    private java.math.BigDecimal reportAmount; // 上报金额(元)
    private java.math.BigDecimal targetAmount; // 策划目标金额(元)
    private java.math.BigDecimal completeAmount; // 已完成目标金额(元)
    private java.math.BigDecimal estimateProfits; // 预计利润(元)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date proposedCompleteTime; // 拟完成时间节点
    private java.lang.String proposedCompleteTimeShow; //拟完成时间节点文本显示
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date completeTime; // 完成时间
    private java.lang.String completeTimeShow; //完成时间文本显示
    private java.lang.String supportingDetails; // 证明资料明细
    private java.math.BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    private java.lang.String firstResponsiblePerson; // 第一责任人
    private java.lang.String mainResponsiblePerson; // 主要负责人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date finalCompleteTime; // (最后)完成时间
    private java.lang.String finalCompleteTimeShow; //(最后)完成时间文本显示
    private java.lang.String attention; // 推荐情况、存在问题、注意事项
    private List<PlanprojectdetailVO> children = new ArrayList<>();
    public List<PlanprojectdetailVO> getChildren() {
        return children;
    }
    public java.lang.String errorMsg;


    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public void setChildren(List<PlanprojectdetailVO> children) {
        this.children = children;
    }


    public String getShadowId() {
        return shadowId;
    }

    public void setShadowId(String shadowId) {
        this.shadowId = shadowId;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 类别及项目名称
     */
    public java.lang.String getCategoryAndName() {
        return categoryAndName;
    }

    /**
     * 类别及项目名称
     */
    public void setCategoryAndName(java.lang.String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    /**
     * 立项理由及依据
     */
    public java.lang.String getInitiateReason() {
        return initiateReason;
    }

    /**
     * 立项理由及依据
     */
    public void setInitiateReason(java.lang.String initiateReason) {
        this.initiateReason = initiateReason;
    }
    /**
     * 立项时间
     */
    public java.util.Date getInitiateDate() {
        return initiateDate;
    }

    /**
     * 立项时间
     */
    public void setInitiateDate(java.util.Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    /**
     * 成本估算(成本分析)(元)
     */
    public java.math.BigDecimal getCostEstimate() {
        return costEstimate;
    }

    /**
     * 成本估算(成本分析)(元)
     */
    public void setCostEstimate(java.math.BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    /**
     * 上报金额(元)
     */
    public java.math.BigDecimal getReportAmount() {
        return reportAmount;
    }

    /**
     * 上报金额(元)
     */
    public void setReportAmount(java.math.BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    /**
     * 策划目标金额(元)
     */
    public java.math.BigDecimal getTargetAmount() {
        return targetAmount;
    }

    /**
     * 策划目标金额(元)
     */
    public void setTargetAmount(java.math.BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    /**
     * 已完成目标金额(元)
     */
    public java.math.BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    /**
     * 已完成目标金额(元)
     */
    public void setCompleteAmount(java.math.BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    /**
     * 预计利润(元)
     */
    public java.math.BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    /**
     * 预计利润(元)
     */
    public void setEstimateProfits(java.math.BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    /**
     * 拟完成时间节点
     */
    public java.util.Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    /**
     * 拟完成时间节点
     */
    public void setProposedCompleteTime(java.util.Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    /**
     * 完成时间
     */
    public java.util.Date getCompleteTime() {
        return completeTime;
    }

    /**
     * 完成时间
     */
    public void setCompleteTime(java.util.Date completeTime) {
        this.completeTime = completeTime;
    }
    /**
     * 证明资料明细
     */
    public java.lang.String getSupportingDetails() {
        return supportingDetails;
    }

    /**
     * 证明资料明细
     */
    public void setSupportingDetails(java.lang.String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    /**
     * 报公司截至本月进度(元)
     */
    public java.math.BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    /**
     * 报公司截至本月进度(元)
     */
    public void setReportToThismonthProgress(java.math.BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    /**
     * 第一责任人
     */
    public java.lang.String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    /**
     * 第一责任人
     */
    public void setFirstResponsiblePerson(java.lang.String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    /**
     * 主要负责人
     */
    public java.lang.String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    /**
     * 主要负责人
     */
    public void setMainResponsiblePerson(java.lang.String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    /**
     * (最后)完成时间
     */
    public java.util.Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    /**
     * (最后)完成时间
     */
    public void setFinalCompleteTime(java.util.Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    /**
     * 推荐情况、存在问题、注意事项
     */
    public java.lang.String getAttention() {
        return attention;
    }

    /**
     * 推荐情况、存在问题、注意事项
     */
    public void setAttention(java.lang.String attention) {
        this.attention = attention;
    }

    public String getInitiateDateShow() {
        return initiateDateShow;
    }

    public void setInitiateDateShow(String initiateDateShow) {
        this.initiateDateShow = initiateDateShow;
    }

    public String getProposedCompleteTimeShow() {
        return proposedCompleteTimeShow;
    }

    public void setProposedCompleteTimeShow(String proposedCompleteTimeShow) {
        this.proposedCompleteTimeShow = proposedCompleteTimeShow;
    }

    public String getCompleteTimeShow() {
        return completeTimeShow;
    }

    public void setCompleteTimeShow(String completeTimeShow) {
        this.completeTimeShow = completeTimeShow;
    }

    public String getFinalCompleteTimeShow() {
        return finalCompleteTimeShow;
    }

    public void setFinalCompleteTimeShow(String finalCompleteTimeShow) {
        this.finalCompleteTimeShow = finalCompleteTimeShow;
    }
}

==> ejc-businessplan-impl-3.0.0-20241021.063348-193-sources.jar: com/ejianc/business/busniessplan/vo/PlanprojectdetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目商务策划立项子表
 * 
 * @author generator
 * 
 */
public class PlanprojectdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String tid;
    private java.lang.String shadowId;
    private java.lang.String tpid;
    private java.lang.String sort; // 序号
    private java.lang.String categoryAndName; // 类别及项目名称
    private java.lang.String initiateReason; // 立项理由及依据
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date initiateDate; // 立项时间
    private java.lang.String initiateDateShow; //立项时间文本显示
    private java.math.BigDecimal costEstimate; // 成本估算(成本分析)(元)
    private java.math.BigDecimal reportAmount; // 上报金额(元)
    private java.math.BigDecimal targetAmount; // 策划目标金额(元)
    private java.math.BigDecimal completeAmount; // 已完成目标金额(元)
    private java.math.BigDecimal estimateProfits; // 预计利润(元)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date proposedCompleteTime; // 拟完成时间节点
    private java.lang.String proposedCompleteTimeShow; //拟完成时间节点文本显示
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date completeTime; // 完成时间
    private java.lang.String completeTimeShow; //完成时间文本显示
    private java.lang.String supportingDetails; // 证明资料明细
    private java.math.BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    private java.lang.String firstResponsiblePerson; // 第一责任人
    private java.lang.String mainResponsiblePerson; // 主要负责人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date finalCompleteTime; // (最后)完成时间
    private java.lang.String finalCompleteTimeShow; //(最后)完成时间文本显示
    private java.lang.String attention; // 推荐情况、存在问题、注意事项
    private List<PlanprojectdetailVO> children = new ArrayList<>();
    public List<PlanprojectdetailVO> getChildren() {
        return children;
    }
    public java.lang.String errorMsg;
    private java.lang.String planContent; // 策划内容
    private java.lang.String planCategory; // 策划类别
    private java.lang.String planType; // 策划类型
    private java.lang.String planStatus; // 策划状态
    private java.lang.String takenMeasures; // 拟采取的措施
    private java.lang.String personLiable; // 责任人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date proposedImplementationTime; // 拟实施时间
    private java.lang.String proposedImplementationTimeShow; // 拟实施时间文本显示
    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public void setChildren(List<PlanprojectdetailVO> children) {
        this.children = children;
    }


    public String getShadowId() {
        return shadowId;
    }

    public void setShadowId(String shadowId) {
        this.shadowId = shadowId;
    }

    public String getProposedImplementationTimeShow() {
        return proposedImplementationTimeShow;
    }

    public void setProposedImplementationTimeShow(String proposedImplementationTimeShow) {
        this.proposedImplementationTimeShow = proposedImplementationTimeShow;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 类别及项目名称
     */
    public java.lang.String getCategoryAndName() {
        return categoryAndName;
    }

    /**
     * 类别及项目名称
     */
    public void setCategoryAndName(java.lang.String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    /**
     * 立项理由及依据
     */
    public java.lang.String getInitiateReason() {
        return initiateReason;
    }

    /**
     * 立项理由及依据
     */
    public void setInitiateReason(java.lang.String initiateReason) {
        this.initiateReason = initiateReason;
    }
    /**
     * 立项时间
     */
    public java.util.Date getInitiateDate() {
        return initiateDate;
    }

    /**
     * 立项时间
     */
    public void setInitiateDate(java.util.Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    /**
     * 成本估算(成本分析)(元)
     */
    public java.math.BigDecimal getCostEstimate() {
        return costEstimate;
    }

    /**
     * 成本估算(成本分析)(元)
     */
    public void setCostEstimate(java.math.BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    /**
     * 上报金额(元)
     */
    public java.math.BigDecimal getReportAmount() {
        return reportAmount;
    }

    /**
     * 上报金额(元)
     */
    public void setReportAmount(java.math.BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    /**
     * 策划目标金额(元)
     */
    public java.math.BigDecimal getTargetAmount() {
        return targetAmount;
    }

    /**
     * 策划目标金额(元)
     */
    public void setTargetAmount(java.math.BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    /**
     * 已完成目标金额(元)
     */
    public java.math.BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    /**
     * 已完成目标金额(元)
     */
    public void setCompleteAmount(java.math.BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    /**
     * 预计利润(元)
     */
    public java.math.BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    /**
     * 预计利润(元)
     */
    public void setEstimateProfits(java.math.BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    /**
     * 拟完成时间节点
     */
    public java.util.Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    /**
     * 拟完成时间节点
     */
    public void setProposedCompleteTime(java.util.Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    /**
     * 完成时间
     */
    public java.util.Date getCompleteTime() {
        return completeTime;
    }

    /**
     * 完成时间
     */
    public void setCompleteTime(java.util.Date completeTime) {
        this.completeTime = completeTime;
    }
    /**
     * 证明资料明细
     */
    public java.lang.String getSupportingDetails() {
        return supportingDetails;
    }

    /**
     * 证明资料明细
     */
    public void setSupportingDetails(java.lang.String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    /**
     * 报公司截至本月进度(元)
     */
    public java.math.BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    /**
     * 报公司截至本月进度(元)
     */
    public void setReportToThismonthProgress(java.math.BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    /**
     * 第一责任人
     */
    public java.lang.String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    /**
     * 第一责任人
     */
    public void setFirstResponsiblePerson(java.lang.String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    /**
     * 主要负责人
     */
    public java.lang.String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    /**
     * 主要负责人
     */
    public void setMainResponsiblePerson(java.lang.String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    /**
     * (最后)完成时间
     */
    public java.util.Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    /**
     * (最后)完成时间
     */
    public void setFinalCompleteTime(java.util.Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    /**
     * 推荐情况、存在问题、注意事项
     */
    public java.lang.String getAttention() {
        return attention;
    }

    /**
     * 推荐情况、存在问题、注意事项
     */
    public void setAttention(java.lang.String attention) {
        this.attention = attention;
    }

    public String getInitiateDateShow() {
        return initiateDateShow;
    }

    public void setInitiateDateShow(String initiateDateShow) {
        this.initiateDateShow = initiateDateShow;
    }

    public String getProposedCompleteTimeShow() {
        return proposedCompleteTimeShow;
    }

    public void setProposedCompleteTimeShow(String proposedCompleteTimeShow) {
        this.proposedCompleteTimeShow = proposedCompleteTimeShow;
    }

    public String getCompleteTimeShow() {
        return completeTimeShow;
    }

    public void setCompleteTimeShow(String completeTimeShow) {
        this.completeTimeShow = completeTimeShow;
    }

    public String getFinalCompleteTimeShow() {
        return finalCompleteTimeShow;
    }

    public void setFinalCompleteTimeShow(String finalCompleteTimeShow) {
        this.finalCompleteTimeShow = finalCompleteTimeShow;
    }

    public String getPlanContent() {
        return planContent;
    }

    public void setPlanContent(String planContent) {
        this.planContent = planContent;
    }

    public String getPlanCategory() {
        return planCategory;
    }

    public void setPlanCategory(String planCategory) {
        this.planCategory = planCategory;
    }

    public String getPlanType() {
        return planType;
    }

    public void setPlanType(String planType) {
        this.planType = planType;
    }

    public String getPlanStatus() {
        return planStatus;
    }

    public void setPlanStatus(String planStatus) {
        this.planStatus = planStatus;
    }

    public String getTakenMeasures() {
        return takenMeasures;
    }

    public void setTakenMeasures(String takenMeasures) {
        this.takenMeasures = takenMeasures;
    }

    public String getPersonLiable() {
        return personLiable;
    }

    public void setPersonLiable(String personLiable) {
        this.personLiable = personLiable;
    }

    public Date getProposedImplementationTime() {
        return proposedImplementationTime;
    }

    public void setProposedImplementationTime(Date proposedImplementationTime) {
        this.proposedImplementationTime = proposedImplementationTime;
    }
}
